@@ -106,6 +106,75 @@ Query historical account balances over a date range:
         "database, which is refreshed every minute)")
     parser.set_defaults(func="quantrocket.account._cli_download_account_balances")
 
+    examples = """
+Download current IB portfolio.
+
+Examples:
+
+View current portfolio in terminal:
+
+    quantrocket account portfolio | csvlook
+
+Download current portfolio for a particular account and save to file:
+
+    quantrocket account portfolio --accounts U12345 -o portfolio.csv
+    """
+    parser = _subparsers.add_parser(
+        "portfolio",
+        help="download current IB portfolio",
+        epilog=examples,
+        formatter_class=argparse.RawDescriptionHelpFormatter)
+    filters = parser.add_argument_group("filtering options")
+    filters.add_argument(
+        "-a", "--accounts",
+        nargs="*",
+        metavar="ACCOUNT",
+        help="limit to these accounts")
+    filters.add_argument(
+        "-t", "--sec-types",
+        nargs="*",
+        metavar="SEC_TYPE",
+        help="limit to these security types")
+    filters.add_argument(
+        "-e", "--exchanges",
+        nargs="*",
+        metavar="EXCHANGE",
+        help="limit to these exchanges")
+    filters.add_argument(
+        "-i", "--conids",
+        nargs="*",
+        metavar="CONID",
+        help="limit to these conids")
+    filters.add_argument(
+        "-s", "--symbols",
+        nargs="*",
+        metavar="SYMBOL",
+        help="limit to these symbols")
+    filters.add_argument(
+        "-z", "--zero",
+        action="store_true",
+        dest="include_zero",
+        help="include zero position rows (default is to exclude them)")
+    outputs = parser.add_argument_group("output options")
+    outputs.add_argument(
+        "-o", "--outfile",
+        metavar="OUTFILE",
+        dest="filepath_or_buffer",
+        help="filename to write the data to (default is stdout)")
+    outputs.add_argument(
+        "-j", "--json",
+        action="store_const",
+        const="json",
+        dest="output",
+        help="format output as JSON (default is CSV)")
+    outputs.add_argument(
+        "-f", "--fields",
+        metavar="FIELD",
+        nargs="*",
+        help="only return these fields (pass '?' or any invalid fieldname to see "
+        "available fields)")
+    parser.set_defaults(func="quantrocket.account._cli_download_account_portfolio")
+
     examples = """
 Query exchange rates for the base currency.
 
