@@ -126,6 +126,14 @@ market data for Australian stocks from the realtime service:
         metavar="HH:MM:SS",
         help="limit to times between these two times (refers to the bar's start time; "
         "mutually exclusive with --times)")
+    parser.add_argument(
+        "--shard",
+        metavar="HOW",
+        choices=["time", "off", "auto"],
+        help="whether and how to shard the database, i.e. break it into smaller pieces. "
+        "Possible choices are `time` (separate database for each bar time), `off` (no "
+        "sharding), or `auto` (decide automatically based on bar size and universe size). "
+        "Default `auto`.")
     parser.add_argument(
         "-n", "--no-config",
         action="store_true",
@@ -148,6 +156,10 @@ Fetch historical data for 3 history databases of Japanese stocks:
 
     quantrocket history fetch 'jpn-lrg-1d' 'jpn-mid-1d' 'jpn-sml-1d'
 
+Fetch how far back data is available but don't yet fetch the data:
+
+    quantrocket history fetch 'usa-stk-15min' --availability
+
 Fetch historical data for a database of US futures, using the priority queue to jump
 in front of other queued requests:
 
@@ -171,15 +183,28 @@ in front of other queued requests:
         "-i", "--conids",
         nargs="*",
         metavar="CONID",
-        help="fetch history for these conids (overrides config)")
+        help="fetch history for these conids, overriding config "
+        "(typically used to fetch a subset of securities)")
+    parser.add_argument(
+        "-u", "--universes",
+        nargs="*",
+        metavar="UNIVERSE",
+        help="fetch history for these universes, overriding config "
+        "(typically used to fetch a subset of securities)")
     parser.add_argument(
         "-s", "--start-date",
         metavar="YYYY-MM-DD",
-        help="fetch history back to this start date (overrides config)")
+        help="fetch history back to this start date, overriding config")
     parser.add_argument(
         "-e", "--end-date",
         metavar="YYYY-MM-DD",
-        help="fetch history up to this end date (overrides config)")
+        help="fetch history up to this end date, overriding config")
+    parser.add_argument(
+        "-a", "--availability",
+        action="store_true",
+        dest="availability_only",
+        help="determine and store how far back data is available but "
+        "don't yet fetch the data")
     parser.add_argument(
         "--delist-missing",
         action="store_true",
@@ -353,6 +378,46 @@ Download a CSV of all historical market data since 2015 from a database called
         "(default is not to stitch together). Possible choices: %(choices)s")
     parser.set_defaults(func="quantrocket.history._cli_download_history_file")
 
+    examples = """
+Query historical market data availability from a history database and download
+to file.
+
+This command is normally called after running:
+
+    quantrocket history fetch [DB] --availability
+
+Examples:
+
+Download a CSV of available start dates by ticker from a database called
+"usa-stk" to a file called start_dates.csv:
+
+    quantrocket history availability usa-stk -o start_dates.csv
+    """
+    parser = _subparsers.add_parser(
+        "availability",
+        help="query historical market data availability from a history database "
+        "and download to file",
+        epilog=examples,
+        formatter_class=argparse.RawDescriptionHelpFormatter)
+    parser.add_argument(
+        "code",
+        metavar="CODE",
+        help="the code of the database to query")
+    outputs = parser.add_argument_group("output options")
+    outputs.add_argument(
+        "-o", "--outfile",
+        metavar="OUTFILE",
+        dest="filepath_or_buffer",
+        help="filename to write the data to (default is stdout)")
+    output_format_group = outputs.add_mutually_exclusive_group()
+    output_format_group.add_argument(
+        "-j", "--json",
+        action="store_const",
+        const="json",
+        dest="output",
+        help="format output as JSON (default is CSV)")
+    parser.set_defaults(func="quantrocket.history._cli_download_history_availability_file")
+
     examples = """
 Return the configuration for a history database.
 
