@@ -211,18 +211,22 @@ Examples:
 
 Generate orders for a single strategy called umd-nyse:
 
-    quantrocket moonshot orders umd-nyse -o orders.csv
+    quantrocket moonshot trade umd-nyse -o orders.csv
 
 Generate orders and automatically place them (if any) through the blotter:
 
-    quantrocket moonshot orders umd-nyse | quantrocket blotter order -f -
+    quantrocket moonshot trade umd-nyse | quantrocket blotter order -f -
 
 Generate orders for multiple strategies for a particular account:
 
-    quantrocket moonshot orders umd-japan hml-japan --accounts DU12345 -o orders.csv
+    quantrocket moonshot trade umd-japan hml-japan --accounts DU12345 -o orders.csv
+
+Generate orders as if it were an earlier date (for prupose of review):
+
+    quantrocket moonshot trade umd-nyse -o orders.csv --review-date 2018-05-11
     """
     parser = _subparsers.add_parser(
-        "orders",
+        "trade",
         help="run one or more strategies and generate orders.",
         epilog=examples,
         formatter_class=argparse.RawDescriptionHelpFormatter)
@@ -236,6 +240,10 @@ Generate orders for multiple strategies for a particular account:
         metavar="ACCOUNT",
         nargs="*",
         help="limit to these accounts")
+    parser.add_argument(
+         "-r", "--review-date",
+         metavar="YYYY-MM-DD",
+         help="generate orders as if it were this date, rather than using today's date")
     parser.add_argument(
         "-j", "--json",
         action="store_true",
@@ -245,7 +253,7 @@ Generate orders for multiple strategies for a particular account:
         metavar="FILEPATH",
         dest="filepath_or_buffer",
         help="the location to write the orders file (omit to write to stdout)")
-    parser.set_defaults(func="quantrocket.moonshot._cli_generate_orders")
+    parser.set_defaults(func="quantrocket.moonshot._cli_trade")
 
     #parser = _subparsers.add_parser("walkforward", help="run walkforward analysis for one or more strategies")
     #parser.add_argument("start_date", metavar="YYYY-MM-DD", help="start date")
@@ -274,15 +282,6 @@ Generate orders for multiple strategies for a particular account:
     #parser.add_argument("-s", "--groupsort", action="store_true", help="sort by origin class (requires -g/--group-by-class), otherwise sort by param name")
     #parser.set_defaults(func="quantrocket.moonshot.get_params")
 
-    #parser = _subparsers.add_parser("trade", help="run one or more strategies and generate orders")
-    #parser.add_argument("strategies", nargs="*", metavar="CODE", help="one or more strategies to trade")
-    #parser.add_argument("-q", "--quotes", action="store_true", help="get realtime quotes asap and append to price history")
-    #parser.add_argument("-t", "--quotes-at", metavar="HH:MM:SS TZ", help="get realtime quotes at the specified time and append to price history")
-    #parser.add_argument("-f", "--quotes-func", metavar="PATH", help="dot-separated path of a function through which the quotes should be passed before appending them to price history")
-    #parser.add_argument("-s", "--save-quotes", metavar="DB", help="instruct the realtime service to save the realtime quotes to this price history database")
-    #parser.add_argument("-r", "--review-date", metavar="YYYY-MM-DD", help="generate trades as if it were this date")
-    #parser.set_defaults(func="quantrocket.moonshot.trade")
-
     #parser = _subparsers.add_parser("shortfall", help="compare live and simulated results")
     #parser.add_argument("start_date", metavar="YYYY-MM-DD", help="start date")
     #parser.add_argument("end_date", nargs="?", metavar="YYYY-MM-DD", help="end date (optional)")
