@@ -574,7 +574,7 @@ def fetch_calendar(exchanges=None):
 def _cli_fetch_calendar(*args, **kwargs):
     return json_to_cli(fetch_calendar, *args, **kwargs)
 
-def list_calendar_statuses(exchanges, sec_type=None, in_=None, ago=None):
+def list_calendar_statuses(exchanges, sec_type=None, in_=None, ago=None, outside_rth=False):
     """
     Check whether exchanges are open or closed.
 
@@ -595,6 +595,10 @@ def list_calendar_statuses(exchanges, sec_type=None, in_=None, ago=None):
         check whether exchanges were open or closed this long ago
         (use Pandas timedelta string, e.g. 2h or 30min or 1d)
 
+    outside_rth : bool
+        check extended hours calendar (default is to check regular
+        trading hours calendar)
+
     Returns
     -------
     dict
@@ -609,6 +613,8 @@ def list_calendar_statuses(exchanges, sec_type=None, in_=None, ago=None):
         params["in"] = in_
     if ago:
         params["ago"] = ago
+    if outside_rth:
+        params["outside_rth"] = outside_rth
 
     response = houston.get("/master/calendar", params=params)
     houston.raise_for_status_with_json(response)
@@ -617,18 +623,100 @@ def list_calendar_statuses(exchanges, sec_type=None, in_=None, ago=None):
 def _cli_list_calendar_statuses(*args, **kwargs):
     return json_to_cli(list_calendar_statuses, *args, **kwargs)
 
-def _cli_isopen(*args, **kwargs):
-    statuses = list_calendar_statuses(*args, **kwargs)
+def _cli_in_status_since(status, since=None, in_=None, ago=None):
+
+    try:
+        import pandas as pd
+    except ImportError:
+        raise ImportError("pandas must be installed to use this command")
+
+    dt = pd.Timestamp.now(status["timezone"])
+    if in_:
+        dt += pd.Timedelta(in_)
+    elif ago:
+        dt -= pd.Timedelta(ago)
+
+    dt = dt.tz_localize(None)
+
+    required_since = pd.date_range(periods=5, end=dt,
+                                   freq=since, normalize=False)
+
+    # For >1D freq, normalize to midnight
+    if required_since.freq.isAnchored() or required_since.freq.rule_code == "D":
+        required_since = pd.date_range(periods=5, end=dt, freq=since, normalize=True)
+        required_since = required_since[-1]
+    else:
+        # If not normalized, the last value is dt, so use the penultimate value
+        required_since = required_since[-2]
+
+    actual_since = pd.Timestamp(status["since"])
+    return actual_since <= required_since
+
+def _cli_in_status_until(status, until=None, in_=None, ago=None):
+
+    try:
+        import pandas as pd
+    except ImportError:
+        raise ImportError("pandas must be installed to use this command")
+
+    dt = pd.Timestamp.now(status["timezone"])
+    if in_:
+        dt += pd.Timedelta(in_)
+    elif ago:
+        dt -= pd.Timedelta(ago)
+
+    dt = dt.tz_localize(None)
+
+    required_until = pd.date_range(start=dt, periods=5,
+                                   freq=until, normalize=False)
+
+    # For >1D freq, normalize to midnight
+    if required_until.freq.isAnchored() or required_until.freq.rule_code == "D":
+        required_until = pd.date_range(start=dt, periods=5,
+                                   freq=until, normalize=True)
+        # due to normalize=True, the date range might include a time before the
+        # start dt; filter it out
+        required_until = required_until[required_until > dt]
+        required_until = required_until[0]
+    else:
+        # If not normalized, the first value is dt, so use the second value
+        required_until = required_until[1]
+
+    actual_until = pd.Timestamp(status["until"])
+    return actual_until >= required_until
+
+def _cli_isopen(exchanges, sec_type=None, in_=None, ago=None, since=None, until=None, outside_rth=False):
+    statuses = list_calendar_statuses(exchanges, sec_type=sec_type, in_=in_, ago=ago, outside_rth=outside_rth)
     is_open = all([
         calendar["status"] == "open" for calendar in statuses.values()
     ])
+    if is_open and since:
+        is_open = all([
+            _cli_in_status_since(status, since=since, in_=in_, ago=ago)
+            for status in statuses.values()])
+
+    elif is_open and until:
+        is_open = all([
+            _cli_in_status_until(status, until=until, in_=in_, ago=ago)
+            for status in statuses.values()])
+
     return '', int(not is_open)
 
-def _cli_isclosed(*args, **kwargs):
-    statuses = list_calendar_statuses(*args, **kwargs)
+def _cli_isclosed(exchanges, sec_type=None, in_=None, ago=None, since=None, until=None, outside_rth=False):
+    statuses = list_calendar_statuses(exchanges, sec_type=sec_type, in_=in_, ago=ago, outside_rth=outside_rth)
     is_closed = all([
         calendar["status"] == "closed" for calendar in statuses.values()
     ])
+    if is_closed and since:
+        is_closed = all([
+            _cli_in_status_since(status, since=since, in_=in_, ago=ago)
+            for status in statuses.values()])
+
+    elif is_closed and until:
+        is_closed = all([
+            _cli_in_status_until(status, until=until, in_=in_, ago=ago)
+            for status in statuses.values()])
+
     return '', int(not is_closed)
 
 def round_to_tick_sizes(infilepath_or_buffer, round_fields,
