@@ -235,7 +235,7 @@ def _cli_scan_parameters(*args, **kwargs):
         kwargs["params"] = dict_strs_to_dict(*params)
     return json_to_cli(scan_parameters, *args, **kwargs)
 
-def generate_orders(strategies, accounts=None, json=False, filepath_or_buffer=None):
+def trade(strategies, accounts=None, review_date=None, json=False, filepath_or_buffer=None):
     """
     Run one or more strategies and generate orders.
 
@@ -249,6 +249,9 @@ def generate_orders(strategies, accounts=None, json=False, filepath_or_buffer=No
     accounts : list of str, optional
         limit to these accounts
 
+    review_date : str (YYYY-MM-DD), optional
+        generate orders as if it were this date, rather than using today's date
+
     json : bool
         format orders as JSON (default is CSV)
 
@@ -264,6 +267,8 @@ def generate_orders(strategies, accounts=None, json=False, filepath_or_buffer=No
         params["strategies"] = strategies
     if accounts:
         params["accounts"] = accounts
+    if review_date:
+        params["review_date"] = review_date
 
     output = "json" if json else "csv"
 
@@ -271,8 +276,12 @@ def generate_orders(strategies, accounts=None, json=False, filepath_or_buffer=No
 
     houston.raise_for_status_with_json(response)
 
+    # Don't write a null response to file
+    if response.content[:4] == b"null":
+        return
+
     filepath_or_buffer = filepath_or_buffer or sys.stdout
     write_response_to_filepath_or_buffer(filepath_or_buffer, response)
 
-def _cli_generate_orders(*args, **kwargs):
-    return json_to_cli(generate_orders, *args, **kwargs)
+def _cli_trade(*args, **kwargs):
+    return json_to_cli(trade, *args, **kwargs)
